MethodChannelDockProgress class

An implementation of DockProgressPlatform that uses method channels.

Inheritance

Constructors

MethodChannelDockProgress()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

changeStyle(ProgressBarStyle style) → Future<void>
Change the style of the progress bar.
override
getProgress() → Future<double?>
Gets the current value of the progress bar.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetProgress() → Future<void>
Resets the current value of the progress bar.
override
setBadgeValue(int value) → Future<void>
Sets the value of the badge indicator, this method will change the style to badge.
override
setProgress(double value) → Future<double?>
Sets the current value of the progress bar.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited