DockProgressPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DockProgressPlatform
Implementers

Constructors

DockProgressPlatform()
Constructs a MacosDockProgressPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

changeStyle(ProgressBarStyle style) → Future<void>
Change the style of the progress bar.
getProgress() → Future<double?>
Gets the current value of the progress bar.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetProgress() → Future<void>
Resets the current value of the progress bar.
setBadgeValue(int value) → Future<void>
Sets the value of the badge indicator, this method will change the style to badge.
setProgress(double value) → Future<double?>
Sets the current value of the progress bar.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ DockProgressPlatform
The default instance of DockProgressPlatform to use.
getter/setter pair